# YARF: Yet Another Raft Framework

## Requirements

- [`poetry`](https://python-poetry.org/)
- [`poem-plugins`](https://github.com/Alviner/poem-plugins) (v1.1 compatible)

## How to develop

- `make develop` - create virtualenv, install develop package
- `make pytest` - run pytest
- `make lint` - run ruff check with mypy
- `make format` - run ruff format
